<?php

declare(strict_types=1);

/**
 * This file is part of Hyperf.
 *
 * @link     https://www.hyperf.io
 * @document https://hyperf.wiki
 * @contact  group@hyperf.io
 * @license  https://github.com/hyperf/hyperf/blob/master/LICENSE
 */

use App\Controller\CompanyController;
use App\Controller\FirstCompanyController;
use App\Controller\PurchaseController;
use App\Controller\RoleController;
use App\Controller\UserController;
use App\Middleware\CheckTokenMiddleware;
use Hyperf\HttpServer\Router\Router;

Router::get('/favicon.ico', function () {
    return '';
});


Router::addGroup('/api/v1/', function () {
    Router::post('user.login', [UserController::class, 'userLogin']);   # 用户登录
});

Router::addGroup('/api/v1', function () {
    Router::addGroup('/', function () {
        /**
         * 用户管理
         */
        Router::post('user.add', [UserController::class, 'addUser']);           # 新增用户
        Router::post('user.list', [UserController::class, 'getUserList']);      # 获取用户列表
        Router::post('user.import', [UserController::class, 'importUser']);     # 批量导入用户信息

        /**
         * 角色管理
         */
        Router::post('role.add', [RoleController::class, 'addRole']);       # 获取用户信息

        /**
         * 采购入库管理
         */
        Router::post('purchase.add', [PurchaseController::class, 'addPurchase']);   # 新增采购入库单

        /**
         * 公司管理
         */
        Router::post('company.add', [CompanyController::class, 'addCompany']);      # 新增公司
        Router::post('company.add.first', [FirstCompanyController::class, 'addFirstCompany']);   # 新增平台公司
    });
}, ['middleware' => [CheckTokenMiddleware::class]]);