<?php

use Hyperf\Database\Schema\Schema;
use Hyperf\Database\Schema\Blueprint;
use Hyperf\Database\Migrations\Migration;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('operator_logs', function (Blueprint $table) {
            $table->unsignedInteger('id', true);
            $table->integer('company_id')->unsigned()->default(0)->comment('公司ID');
            $table->smallInteger('type')->default(0)->comment('日志类型');
            $table->string('log_title', 120)->default('')->comment('日志主题');
            $table->string('route', 255)->default('')->comment('路由名称');
            $table->json('params')->comment('参数');
            $table->integer('ip')->default(0)->comment('IP地址')->unsigned();
            $table->string('location', 255)->default('')->comment('IP定位地址');
            $table->tinyInteger('source')->default(0)->comment('客户端操作来源：1PC端 2手机端 3对外服务SDK接口 4后台执行日志');
            $table->float('timer', 8, 3)->default(0)->comment('接口请求时间');
            $table->string('agent', 255)->default('')->comment('客户端浏览器内核');
            $table->text('remark')->comment('日志备注');
            $table->integer('creator_id')->default(0)->unsigned()->comment('创建人ID');
            $table->string('creator_name', 45)->default('')->comment('创建人姓名');
            $table->integer('created_at')->default(0)->unsigned()->comment('创建时间');
            $table->integer('updated_at')->default(0)->unsigned()->comment('更新时间');

            $table->index(['source', 'type', 'company_id', 'created_at', 'id'], 'idx_mes_logs_full');
            $table->comment('日志管理表');
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('operator_logs');
    }
};
